<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL" sourcelanguage="en">
<context>
    <name>About</name>
    <message>
        <location filename="../../src/about.ui" line="17"/>
        <source>About KDiskMark</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="62"/>
        <source>Version:</source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="88"/>
        <source>License:</source>
        <translation>Licencja:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="114"/>
        <source>Author:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="146"/>
        <source>E-mail:</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="178"/>
        <source>Flexible I/O Tester:</source>
        <translation>Flexible I/O Tester:</translation>
    </message>
    <message>
        <location filename="../../src/about.ui" line="204"/>
        <source>Application Icon:</source>
        <translation>Ikona aplikacji:</translation>
    </message>
</context>
<context>
    <name>Benchmark</name>
    <message>
        <location filename="../../src/benchmark.cpp" line="232"/>
        <source>Preparing...</source>
        <translation>Przygotowywanie...</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="254"/>
        <source>Sequential Read %1/%2</source>
        <translation>Odczyt sekwencyjny %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="264"/>
        <source>Sequential Write %1/%2</source>
        <translation>Zapis sekwencyjny %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="274"/>
        <source>Sequential Mix %1/%2</source>
        <translation>Mix sekwencyjny %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="405"/>
        <source>Could not obtain administrator privileges.</source>
        <translation>Nie udało się uzyskać uprawnień administratora.</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="258"/>
        <source>Random Read %1/%2</source>
        <translation>Odczyt losowy %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="268"/>
        <source>Random Write %1/%2</source>
        <translation>Zapis losowy %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="278"/>
        <source>Random Mix %1/%2</source>
        <translation>Mix losowy %1/%2</translation>
    </message>
    <message>
        <location filename="../../src/benchmark.cpp" line="285"/>
        <source>Interval Time %1/%2 sec</source>
        <translation>Przerwa %1/%2 s</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/mainwindow.ui" line="30"/>
        <location filename="../../src/mainwindow.cpp" line="917"/>
        <source>All</source>
        <translation>Wszystkie</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="351"/>
        <location filename="../../src/mainwindow.ui" line="933"/>
        <location filename="../../src/mainwindow.cpp" line="547"/>
        <source>Read</source>
        <translation>Odczyt</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="520"/>
        <location filename="../../src/mainwindow.ui" line="952"/>
        <location filename="../../src/mainwindow.cpp" line="550"/>
        <source>Write</source>
        <translation>Zapis</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="686"/>
        <location filename="../../src/mainwindow.cpp" line="553"/>
        <source>Mix</source>
        <translation>Mix</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="220"/>
        <location filename="../../src/mainwindow.cpp" line="436"/>
        <location filename="../../src/mainwindow.cpp" line="440"/>
        <source>MB/s</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="225"/>
        <source>GB/s</source>
        <translation>GB/s</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="230"/>
        <location filename="../../src/mainwindow.cpp" line="442"/>
        <location filename="../../src/mainwindow.cpp" line="443"/>
        <source>IOPS</source>
        <translation>IOPS</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="235"/>
        <location filename="../../src/mainwindow.cpp" line="445"/>
        <location filename="../../src/mainwindow.cpp" line="446"/>
        <source>μs</source>
        <translation>μs</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1017"/>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1025"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1029"/>
        <source>Test Data</source>
        <translation>Dane testowe</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1047"/>
        <source>Profile</source>
        <translation>Profil</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1063"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1067"/>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1075"/>
        <source>Theme</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1091"/>
        <source>About KDiskMark</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1096"/>
        <source>Queues &amp;&amp; Threads</source>
        <translation>Kolejki i wątki</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1101"/>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1106"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1111"/>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1122"/>
        <source>Default</source>
        <translation>Domyślny</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1130"/>
        <source>Peak Performance</source>
        <translation>Najwyższa wydajność</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1138"/>
        <source>Real World Performance</source>
        <translation>Rzeczywista wydajność</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1146"/>
        <source>Default [+Mix]</source>
        <translation>Domyślny [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1154"/>
        <source>Peak Performance [+Mix]</source>
        <translation>Najwyższa wydajność [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1162"/>
        <source>Real World Performance [+Mix]</source>
        <translation>Rzeczywista wydajność [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1173"/>
        <source>Flush Pagecache</source>
        <translation>Oczyść cache dysku</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1181"/>
        <source>Demo</source>
        <translation>Demonstracyjny</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1192"/>
        <source>Read and Write [+Mix]</source>
        <translation>Odczyt i zapis [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1200"/>
        <source>Read [+Mix]</source>
        <translation>Odczyt [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1208"/>
        <source>Write [+Mix]</source>
        <translation>Zapis [+Mix]</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1219"/>
        <source>Random</source>
        <translation>Losowe</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1227"/>
        <source>Fill with zeros</source>
        <translation>Wypełnij zerami</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1238"/>
        <source>Standard Preset</source>
        <translation>Standardowe ustawienie</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1246"/>
        <source>NVMe SSD</source>
        <translation>NVMe SSD</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1257"/>
        <source>Use Fusion</source>
        <translation>Fusion</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1265"/>
        <source>Stylesheet Light</source>
        <translation>Arkusz stylów Light</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1273"/>
        <source>Stylesheet Dark</source>
        <translation>Arkusz stylów Dark</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1281"/>
        <source>Do not apply</source>
        <translation>Nie stosuj</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1292"/>
        <source>Use O_DIRECT</source>
        <translation>Użyj opcji O_DIRECT</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="1303"/>
        <source>CoW detection</source>
        <translation>Wykrywanie CoW</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="54"/>
        <source>The device is encrypted. Performance may drop.</source>
        <translation>Urządzenie jest zaszyfrowane. Wydajność może być niższa.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="352"/>
        <location filename="../../src/mainwindow.cpp" line="452"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="356"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>Bytes</source>
        <translation>Bajtów</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="452"/>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="263"/>
        <location filename="../../src/mainwindow.cpp" line="322"/>
        <source>Add a directory</source>
        <translation>Dodaj katalog</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="520"/>
        <source>PiB</source>
        <translation>PiB</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="892"/>
        <location filename="../../src/mainwindow.cpp" line="893"/>
        <location filename="../../src/mainwindow.cpp" line="894"/>
        <location filename="../../src/mainwindow.cpp" line="895"/>
        <location filename="../../src/mainwindow.cpp" line="896"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="944"/>
        <source>Stopping...</source>
        <translation>Zatrzymywanie...</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="954"/>
        <source>Not available</source>
        <translation>Nie dostępne</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="954"/>
        <source>Directory is not specified.</source>
        <translation>Nie określono katalogu.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="1059"/>
        <source>Copy-on-Write (CoW) is enabled on the selected directory.</source>
        <translation>Kopirowanie przy zapisie (CoW) jest włączone w wybranym katalogu.</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="1060"/>
        <source>This may affect performance results. Would you like to create a new subdirectory with CoW disabled?</source>
        <translation>Może to wpłynąć na wyniki wydajności. Utworzyć nowy podkatalog z wyłączonym CoW?</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation type="vanished">Potwierdź</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="964"/>
        <source>Benchmark Failed</source>
        <translation>Testowanie nie powiodło się</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/global.cpp" line="25"/>
        <source>&lt;h2&gt;%1 %2 %3&lt;br/&gt;Queues=%4&lt;br/&gt;Threads=%5%6&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;%1 %2 %3&lt;br/&gt;Kolejki=%4&lt;br/&gt;Wątki=%5%6&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="26"/>
        <source>Sequential</source>
        <translation>Sekwencyjne</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="26"/>
        <source>Random</source>
        <translation>Losowe</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="28"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="28"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../src/global.cpp" line="34"/>
        <source>&lt;h1&gt;%1 MB/s&lt;br/&gt;%2 GB/s&lt;br/&gt;%3 IOPS&lt;br/&gt;%4 μs&lt;/h1&gt;</source>
        <translation>&lt;h1&gt;%1 MB/s&lt;br/&gt;%2 GB/s&lt;br/&gt;%3 IOPS&lt;br/&gt;%4 μs&lt;/h1&gt;</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="200"/>
        <source>No FIO was found. Please install FIO before using KDiskMark.</source>
        <translation>Nie znaleziono programu FIO. Proszę zainstalować FIO przed użyciem KDiskMark.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../../src/settings.ui" line="14"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="149"/>
        <source>Block Size</source>
        <translation>Rozmiar bloku</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="165"/>
        <source>Queues</source>
        <translation>Kolejki</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="181"/>
        <source>Threads</source>
        <translation>Wątki</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="280"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="335"/>
        <source>Profile: Peak Performance</source>
        <translation>Profil: Najwyższa wydajność</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="446"/>
        <source>Profile: Demo</source>
        <translation>Profil: Demonstracyjny</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="508"/>
        <source>Measuring time</source>
        <translation>Czas pomiaru</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="530"/>
        <source>Interval time</source>
        <translation>Czas przerwy</translation>
    </message>
    <message>
        <location filename="../../src/settings.ui" line="257"/>
        <source>Profile: Default</source>
        <translation>Profil: Domyślny</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="18"/>
        <location filename="../../src/settings.cpp" line="23"/>
        <source>sec</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="19"/>
        <location filename="../../src/settings.cpp" line="24"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="71"/>
        <location filename="../../src/settings.cpp" line="72"/>
        <location filename="../../src/settings.cpp" line="73"/>
        <location filename="../../src/settings.cpp" line="74"/>
        <location filename="../../src/settings.cpp" line="76"/>
        <location filename="../../src/settings.cpp" line="77"/>
        <location filename="../../src/settings.cpp" line="79"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="59"/>
        <location filename="../../src/settings.cpp" line="60"/>
        <location filename="../../src/settings.cpp" line="61"/>
        <location filename="../../src/settings.cpp" line="62"/>
        <location filename="../../src/settings.cpp" line="64"/>
        <location filename="../../src/settings.cpp" line="65"/>
        <location filename="../../src/settings.cpp" line="67"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
</context>
</TS>
